/*!
 * Example: multi line autocomplete box based on jQuery
 *
 * Copyright © 2015 kaempf-nk.de
 * Licensed under the MIT license
 * http://www.kaempf-nk.de/webseitengestaltung/js/license.txt
 *
 *
 * History: 2015-11-22 - first release
 */
$(document).on("focus","#SearchBox",function(e) {

	var cache = {};

	if ( !$(this).data("autocomplete") ) { 		// If the autocomplete wasn't called yet
		
		function getAddressCard (item) {		// output formating

        	var sAddressCard ='';
        	if (typeof(item.Empty) != 'undefined') {
        		sAddressCard += item.Empty;
        	} else {
        		
            	if (item.Company != null) sAddressCard += '<b>' + item.Company + '</b><br />';
            	if (item.Surname != null) sAddressCard += item.Surname;
            	if (item.Givenname != null) sAddressCard += ' '+item.Givenname;
            	if (item.Surname != null || item.Givenname != null) sAddressCard += '<br />';

            	if (item.Street != null) sAddressCard += item.Street + '<br />';
            	if (item.Country != null) sAddressCard += item.Country + ' -';
            	if (item.Zipcode != null) sAddressCard += ' ' + item.Zipcode;
            	if (item.Location != null) sAddressCard += ' ' + item.Location;
        	}
        	
        	return sAddressCard;
		}
		
        $(this).autocomplete({             			// call autocomplete
        	minLength: 2,							// start to search after two letters input as minimum
        	create: function () {
                $(this).data('ui-autocomplete')._renderItem = function (ul, item) {

                	var sAddressCard = getAddressCard(item); // get formated address card
	                	
					var aTerm = $.trim(this.term).split(" ");
                	for (var i=0;i<aTerm.length;i++) {		// highlight term(s)
                		sAddressCard = sAddressCard.replace(new RegExp("(?![^&;]+;)(?!<[^<>]*)(" + $.ui.autocomplete.escapeRegex(aTerm[i]) + ")(?![^<>]*>)(?![^&;]+;)", "gi"), "<span>$1</span>");
                	}

                    return $('<li>')
						.data( "ui-autocomplete", item )
                        .append(sAddressCard)
                        .appendTo(ul);
                };
            },
            focus: function( event, data ) {
            	return false;
            },
        	source: function(request, response) {
        		var term = request.term;
        		
        		function getResult(data) {			// getResult as function, due to the usage in ajax.success and read from cache
        			if (data.length == 0) {
                        return([{Empty: "No entry found"}]);
        			} else {
	        			return $.map( data, function(item) {
	                		return {
	                			Company: item.company,
	                			Surname: item.surname,
	                			Givenname: item.givenname,
	                			Street: item.street,
	                			Country: item.country,
	                			Zipcode: item.zipcode,
	                			Location: item.location
	                		};
	                	});
        			}
        		};
        		
            	if ( term in cache ) {				// read from cache, if term already exists
             		response(getResult(cache[term]));
	            	return false;
            	}

                $.ajax({							// ajax-call for new terms
                    url: "http://web-tipps.safe-ws.de/appl/jquery-autocomplete/reqAddressData.php",
                    data: {
                    	term: request.term
                    },
                    type: "GET",
                    dataType: 'jsonp',
                    success: function (data) {
                     	cache[term] = data;
                    	response(getResult(data));
                    }
                });
            },
            select: function( event, data) {		// put selected item into divResult
            	if (data.item) {
            		$('#divResult').html(getAddressCard(data.item));
            	}
            	return false;
            }
        });
    }
});
